@@ -211,7 +211,11 @@ class RagSubNamespace(GatewayMixin):
         slug: str,
         identifier: str,
         content: str,
+        name: Optional[str] = None,
+        description: Optional[str] = None,
         category: Optional[str] = None,
+        subcategory: Optional[str] = None,
+        source_reference: Optional[Dict[str, Any]] = None,
         metadata: Optional[Dict[str, Any]] = None
     ) -> Dict[str, Any]:
         """
@@ -220,13 +224,25 @@ class RagSubNamespace(GatewayMixin):
         Args:
             slug: Corpus identifier
             identifier: Entry identifier (unique within corpus)
-            content: Text content to embed
+            content: Text content to embed (stored as content_markdown)
+            name: Optional human-readable name
+            description: Optional brief description
             category: Optional category for filtering
+            subcategory: Optional subcategory
+            source_reference: Optional source attribution
             metadata: Optional metadata dict
         """
-        body: Dict[str, Any] = {"content": content}
+        body: Dict[str, Any] = {"content_markdown": content}
+        if name:
+            body["name"] = name
+        if description:
+            body["description"] = description
         if category:
             body["category"] = category
+        if subcategory:
+            body["subcategory"] = subcategory
+        if source_reference:
+            body["source_reference"] = source_reference
         if metadata:
             body["metadata"] = metadata
 
@@ -260,11 +276,30 @@ class RagSubNamespace(GatewayMixin):
 
         Args:
             slug: Corpus identifier
-            entries: List of {"identifier", "content", "category", "metadata"} dicts
+            entries: List of entry dicts with:
+                - identifier: string (required)
+                - content: string (required) - Will be sent as content_markdown
+                - name: string (optional)
+                - description: string (optional)
+                - category: string (optional)
+                - subcategory: string (optional)
+                - source_reference: dict (optional)
+                - metadata: dict (optional)
+
+        Returns:
+            Dict with "processed", "failed", "errors" counts
         """
+        # Transform 'content' to 'content_markdown' for API compatibility
+        transformed = []
+        for entry in entries:
+            e = dict(entry)
+            if "content" in e and "content_markdown" not in e:
+                e["content_markdown"] = e.pop("content")
+            transformed.append(e)
+
         return await self._api(
             endpoint=f"/api/rag/{slug}/bulk",
-            body={"entries": entries}
+            body={"entries": transformed}
         )
 
     async def search(
@@ -390,16 +425,12 @@ class ArtifactsSubNamespace(GatewayMixin):
     async def get(
         self,
         artifact_id: str,
-        conversation_id: Optional[str] = None
+        conversation_id: str
     ) -> Dict[str, Any]:
         """Get artifact by ID."""
-        body: Dict[str, Any] = {"artifact_id": artifact_id}
-        if conversation_id:
-            body["conversation_id"] = conversation_id
-
         return await self._api(
-            endpoint=f"/api/agent/artifacts/{artifact_id}",
-            body=body
+            endpoint=f"/api/agent/artifacts/{artifact_id}?conversation_id={conversation_id}",
+            method="GET"
         )
 
     async def create(
@@ -407,27 +438,28 @@ class ArtifactsSubNamespace(GatewayMixin):
         name: str,
         content: str,
         conversation_id: str,
-        artifact_type: str = "text",
+        artifact_type: str = "text/plain",
+        is_base64: bool = False,
         metadata: Optional[Dict[str, Any]] = None
     ) -> Dict[str, Any]:
         """
         Create a new artifact.
 
         Args:
-            name: Artifact name/filename
-            content: Artifact content (text or base64 for binary)
+            name: Artifact key/filename
+            content: Artifact content (text or base64-encoded for binary)
             conversation_id: Associated conversation ID
-            artifact_type: Type of artifact (text, code, image, etc.)
-            metadata: Optional metadata dict
+            artifact_type: MIME content type (e.g., "text/plain", "text/html", "image/png")
+            is_base64: If True, content is base64-encoded binary
+            metadata: Optional metadata dict (not stored, for SDK use)
         """
         body: Dict[str, Any] = {
-            "name": name,
+            "key": name,
             "content": content,
             "conversation_id": conversation_id,
-            "type": artifact_type
+            "content_type": artifact_type,
+            "is_base64": is_base64
         }
-        if metadata:
-            body["metadata"] = metadata
 
         return await self._api(
             endpoint="/api/agent/artifacts",
@@ -436,38 +468,24 @@ class ArtifactsSubNamespace(GatewayMixin):
 
     async def list(
         self,
-        conversation_id: str,
-        limit: int = 100,
-        offset: int = 0
+        conversation_id: str
     ) -> List[Dict[str, Any]]:
         """List artifacts for a conversation."""
-        body: Dict[str, Any] = {
-            "conversation_id": conversation_id,
-            "limit": limit,
-            "offset": offset
-        }
-
         result = await self._api(
-            endpoint="/api/agent/artifacts",
-            method="GET",
-            body=body
+            endpoint=f"/api/agent/artifacts?conversation_id={conversation_id}",
+            method="GET"
         )
         return result.get("artifacts", result) if isinstance(result, dict) else result
 
     async def delete(
         self,
         artifact_id: str,
-        conversation_id: Optional[str] = None
+        conversation_id: str
     ) -> Dict[str, Any]:
         """Delete an artifact."""
-        body: Dict[str, Any] = {}
-        if conversation_id:
-            body["conversation_id"] = conversation_id
-
         return await self._api(
-            endpoint=f"/api/agent/artifacts/{artifact_id}",
-            method="DELETE",
-            body=body if body else None
+            endpoint=f"/api/agent/artifacts/{artifact_id}?conversation_id={conversation_id}",
+            method="DELETE"
         )
 
 
@@ -900,10 +918,10 @@ class AiNamespace(GatewayMixin):
             List of history messages
         """
         result = await self._api(
-            endpoint=f"/api/agent/history/{conversation_id}",
-            body={"limit": limit}
+            endpoint=f"/api/agent/history/{conversation_id}?limit={limit}",
+            method="GET"
         )
-        return result.get("history", result) if isinstance(result, dict) else result
+        return result.get("messages", result) if isinstance(result, dict) else result
 
     # ========================================
     # LLM Completions
